@@ -2,7 +2,7 @@ package RedisDB::Cluster;
 
 use strict;
 use warnings;
-our $VERSION = "2.40";
+our $VERSION = "2.41";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -252,7 +252,7 @@ sub execute {
     }
     my $slot     = key_slot($key);
     my $node_key = $self->{_slots}[$slot]
-      // "$self->{_nodes}[0]{host}:$self->{_nodes}[0]{port}";
+      || "$self->{_nodes}[0]{host}:$self->{_nodes}[0]{port}";
     my $asking;
     my $last_connection;
 
